#include <math.h>
#include "cbw.h"

/* variables pour la librairie universelle */
extern const float RevNum;
extern const int ODOM_BoardNum;
extern float DLLRevNum;
extern float VXDRevNum;

int nLeCompteur; /* Nombre de compteurs sur la carte */
int nQuadrature; /* Multiplicateur de rsolution, ou dsactivation de la 
				    quadrature : les compteurs sont utiliss comme de 
					simples compteurs TTL */
int nModeComptage; /* Mode de Comptage */
int nEncodageDonnees; /*Codage BCD ou Binaire */
int nModeIndex; /* Selection de l'action sur le signal Index */
int nInvertionIndex; /* Polarit du signal Index */
int nFlagPins; /* Slection des signaux reprsents par FLG1 et FLG2 */
int nGating; 

/*****************************************************************************
 * InitCompteurs
 *****************************************************************************/
int InitCompteursOdom( )
{
	int nCodeRetour;
		
	nQuadrature = X4_QUAD;
	nModeComptage = NORMAL_MODE; /* les compteurs sont sur 24 bits */
	nEncodageDonnees = BINARY_ENCODING;
	nModeIndex = INDEX_DISABLED;
	nInvertionIndex = ENABLED;
	nFlagPins = CARRY_BORROW;
	nGating = DISABLED;

	/* Configuration des compteurs */
	/* Compteur 1 */
	nLeCompteur = 1;
	nCodeRetour = cbC7266Config( ODOM_BoardNum, nLeCompteur, nQuadrature, nModeComptage,
		nEncodageDonnees, nModeIndex, nInvertionIndex, nFlagPins, nGating );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nLeCompteur = 2;
	nCodeRetour = cbC7266Config( ODOM_BoardNum, nLeCompteur, nQuadrature, nModeComptage,
		nEncodageDonnees, nModeIndex, nInvertionIndex, nFlagPins, nGating );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	/* Rglage des prescaler */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESCALER1, ( unsigned long )( 5 ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESCALER2, ( unsigned long )( 5 ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	/* Initialisation des compteurs */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT1, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT2, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	/* Initialisation des presets */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET1, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET2, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	return NOERRORS;
}

/*****************************************************************************
 * InitCompteurs
 *****************************************************************************/
int RAZCompteursOdom( )
{
	int nCodeRetour;

	/* Initialisation des compteurs */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT1, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT2, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	/* Initialisation des presets */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET1, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET2, ( unsigned long )( pow( 2,23 ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	return NOERRORS;
}

/*****************************************************************************
 * Mise  une valeur des Compteurs
 *****************************************************************************/
int SETCompteursOdom( long ctn1, long ctn2 )
{
	int nCodeRetour;

	/* Initialisation des compteurs */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT1, ( unsigned long )( - (ctn1 + ( long )( pow( 2,23 ) ) ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, COUNT2, ( unsigned long )( ctn2 + ( long )( pow( 2,23 ) ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	/* Initialisation des presets */
	/* Compteur 1 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET1, ( unsigned long )( - ( ctn1 + ( long )( pow( 2,23 ) ) ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;
	/* Compteur 2 */
	nCodeRetour = cbCLoad32( ODOM_BoardNum, PRESET2, ( unsigned long )( ctn2 + ( long )( pow( 2,23 ) ) ) );
	if( nCodeRetour != 0 )
		return nCodeRetour;

	return NOERRORS;
}

/*****************************************************************************
 * LireCompteurs
 *****************************************************************************/
long LireCompteurOdom( int nIdxCompteur )
{
	unsigned long nValTemp;
	int nCodeRetour;
	
	nCodeRetour = cbCIn32( ODOM_BoardNum, nIdxCompteur, &nValTemp );
	if( nCodeRetour == NOERRORS )
		return ( long )( nValTemp - ( unsigned long )( pow( 2,23 ) ) );
	else
		return ( long )( nCodeRetour );
}






