/***************************************************************************
 *            routineodo.h
 *
 *  Tue Apr 19 11:01:31 2005
 *  Copyright  2005  Yann MORERE
 *  morere@sciences.univ-metz.fr
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef ROUTINE_ODO 
#define CODEUR1 "/proc/pci_quad04/cntr_1"
#define CODEUR2 "/proc/pci_quad04/cntr_2"
#define CODEUR3 "/proc/pci_quad04/cntr_3"
#define CODEUR4 "/proc/pci_quad04/cntr_4"
#define SET_CODEUR1 "/proc/pci_quad04/set_1"
#define SET_CODEUR2 "/proc/pci_quad04/set_2"
#define SET_CODEUR3 "/proc/pci_quad04/set_3"
#define SET_CODEUR4 "/proc/pci_quad04/set_4"
#endif

/*
 * Defines for registers and bits for the LS7266R1 
 * Quadrature Counter Chip used on the Measurement Computing
 * PCI-QUAD04 board.
 */

/* Primary Registers */
#define X_1DATA(arg)  (arg+0)	// X_1 Data register
#define X_1CMD(arg)   (arg+1)	// X_1 Command register
#define Y_1DATA(arg)  (arg+2)	// Y_1 Data register
#define Y_1CMD(arg)   (arg+3)	// Y_1 Command register
#define X_2DATA(arg)  (arg+4)	// X_2 Data register
#define X_2CMD(arg)   (arg+5)	// X_2 Command register
#define Y_2DATA(arg)  (arg+6)	// Y_2 Data register
#define Y_2CMD(arg)   (arg+7)	// Y_2 Command register

/* Reset and Load Register */
#define  RLD(arg)   (arg | 0x80)// select both counters X&Y
#define XRLD(arg)   (arg | 0 )
#define YRLD(arg)   XRLD(arg)
#define Rst_BP      0x01
#define Rst_CNTR    0x02
#define Rst_FLAGS   0x04
#define Rst_E       0x06
#define Trf_PR_CNTR 0x08
#define Trf_Cntr_OL 0x10
#define Trf_PS0_PSC 0x18

/* Counter Mode Register */
#define  CMR(arg)   (arg | 0xA0) // select both counters X&Y
#define XCMR(arg)   (arg | 0x20)
#define YCMR(arg)   XCMR(arg)
#define BINCnt      0x00	// Count Binary
#define BCDCnt      0x01	// Count BCD
#define NrmCnt      0x00	// Normal Counting
#define RngLmt      0x02	// Range Limit 
#define NRcyc       0x04	// Non-Recycle count
#define ModN        0x06	// Modulo N counting
#define NQDX        0x00	// Non-quad (UP/DN)
#define QDX1        0x08	// Quad X1
#define QDX2        0x10	// Quad X2
#define QDX4        0x18	// Quad X4

/* Input/Output Control Register */
#define  IOR(arg)   (arg | 0xC0)// select both counters X&Y
#define XIOR(arg)   (arg | 0x40)
#define YIOR(arg)   XIOR(arg)
#define DisAB       0x00	// Disable A&B inputs
#define EnAB        0x01	// Enable A&B inputs
#define LCNTR       0x00	// LCNTR/LOL is CNTR input
#define LOL         0x02        // LCNTR/LOL is Load OL input
#define RCNTR       0x00	// RCNTR/ABG is CNTR input
#define ABGate      0x04	// RCNTR/ABG is A&B Enable Gate
#define CYBW        0x00	// FLG1-Carry FLG2-Borrow
#define CPBW        0x08	// FLG1-Compare FLG2-Borrow
#define CB_UPDN     0x10	// FLG1-Carry/Borrow FLG2-UP/DN
#define IDX_ERR     0x18	// FLG1-IDX FLG2-E

/* Index Control Register */
#define  IDR(arg)   (arg | 0xE0)// select both counters X&Y
#define XIDR(arg)   (arg | 0x60)
#define YIDR(arg)   XIDR(arg)
#define DisIDX      0x00	// Disable Index
#define EnIDX       0x01	// Enable Index 
#define NIDX        0x00	// Negative Index Polarity
#define PIDX        0x02	// Positive Index Polarity
#define LIDX        0x00	// LCNTR/LOL pin is Index
#define RIDX        0x04	// RCNTR/ABG pin is Index

/* Interrupt Routing Control Register */
#define IRCR(arg)   (arg + 8)   // Register Address
#define CBINT1      0x10	// Carry/Borrow Interrupt Ch 1
#define CBINT2      0x20	// Carry/Borrow Interrupt Ch 2
#define CBINT3      0x40	// Carry/Borrow Interrupt Ch 3
#define CBINT4      0x80	// Carry/Borrow Interrupt Ch 4
#define IND1SEL     0x01        // Index 1 Select
#define IND2SEL     0x02        // Index 2 Select
#define IND3SEL     0x04        // Index 3 Select
#define IND4SEL     0x08        // Index 4 Select
#define INDSEL      0x0F        // Index All Select

/* Input Signal Control Register */
#define ISCR(arg)   (arg + 9)   // Register Address
#define PH2A        0x01        // FLG1 to PH2A
#define PH2B        0x02        // PH1B to PH2B
#define PH3A        0x04        // FLG2 to PH3A
#define PH3B        0x08        // PH2B to PH3B
#define PH4A        0x10        // FLG3 to PH4A
#define PH4B0       0x20        // PH2B to PH4B
#define PH4B1       0x40        // PH3B to PH4B
#define CNTR_4_24   0x00        // Four 24 bit counters (1/2/3/4)
#define CNTR_1_48   (PH2A+PH2B) // One 48 bit counter Two 24 bit (1-2/3/4)
#define CNTR_2_48   (PH2A+PH2B+PH4A+PH4B1) // Two 48 bit counters (1-2/3-4)
#define CNTR_24_72  (PH3A+PH3B+PH4A+PH4B0) // One 24 (1) and one 72 bit (2-3-4)
#define CNTR_96     (PH2A+PH2B+PH3A+PH3B+PH4A+PH4B0) // One 96 bit (1-2-3-4)

/* Programmable Interrupt Controllers */
#define PIC_A(arg)  (arg + 10)  // PIC Port A
#define PIC_B(arg)  (arg + 11)  // PIC Port B

gint config_codeur(gchar * nom_codeur);
gint init_codeur(gchar * nom_codeur, glong valeur);
glong lectureODO(gchar * nom_codeur, gint sens);
