/***************************************************************************
 *            routineus.c
 *
 *  Thu Mar 31 15:21:07 2005
 *  Copyright  2005  Yann MORERE
 *  morere@sciences.univ-metz.fr
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 

#include <stdio.h>   /* Standard input/output definitions */
#include <string.h>  /* String function definitions */
#include <unistd.h>  /* UNIX standard function definitions */
#include <fcntl.h>   /* File control definitions */
#include <errno.h>   /* Error number definitions */
#include <termios.h> /* POSIX terminal control definitions */

#include "routineus.h"
/*
* 'open_port()' - Open serial port 1.
*
     * Returns the file descriptor on success or -1 on error.
*/

int
open_port(char * nom_port)
{
	int fd; /* File descriptor for the port */
	struct termios options; /*options à récupérer*/
		
	/*ouverture du port*/
	fd = open(nom_port, O_RDWR | O_NOCTTY | O_NDELAY);
    if (fd == -1)
      {
    /*
	* Could not open the port.
	*/
	perror("open_port: Unable to open Port");
      }
      else
		fcntl(fd, F_SETFL, 0);

		/*configuration du port*/
		/* recupère les options courante */
    	tcgetattr(fd, &options);
    	
	  	/*
     	* Fixe la vitesse du port 9600...
     	*/
	    cfsetispeed(&options, B9600);
    	cfsetospeed(&options, B9600);

		/* Fixe 8 bits, pas de bits de stop, 1 bits de parité */
	  	options.c_cflag &= ~PARENB; /*pas de bit de parité*/
		options.c_cflag &= ~CSTOPB; /*1 bit de stop*/
		options.c_cflag &= ~CSIZE; /*pour la taille des données*/
		options.c_cflag |= CS8; /*8 bits*/
	  	/*options.c_cflag |= CNEW_RTSCTS;*/ /* contrôle de flux matériel*/
	  
    	/* set raw input, 1 second timeout */
    	options.c_cflag     |= (CLOCAL | CREAD);
    	options.c_lflag     &= ~(ICANON | ECHO | ECHOE | ISIG);
/*    	options.c_cc[VMIN]  = 0;
    	options.c_cc[VTIME] = 10;*/

		/* Output */
		options.c_oflag &= ~OPOST; /*output en mode raw*/
    	/* set the options */
    	tcsetattr(fd, TCSANOW, &options);	 
		/*fputs("Ouverture Port\n", stderr);				*/
	  
      return (fd);
    }
	
void close_port(int fd)	
	{
	close(fd);
	/*fputs("Fermeture Port\n", stderr);		*/
	}
	
void demarrer68HC11(int fd)
{
	int n;
	char buffer[1]="D"; /*démarrer*/
	n = write(fd, buffer, 1);
    if (n < 0)
      fputs("write() of D failed!\n", stderr);
	/*fputs("Démarrage 68HC11\n", stderr);*/
	sprintf(buffer,"%c",'C'); /*vitesse de capture*/
	n = write(fd, buffer, 1);
    if (n < 0)
      fputs("write() of D failed!\n", stderr);
	/*fputs("vitesse 68HC11\n", stderr);*/
}	

void stopper68HC11(int fd)
{
	int n;
	char buffer[1]="F";
	n = write(fd, buffer, 1);
    if (n < 0)
      fputs("write() of F failed!\n", stderr);
	/*fputs("Arrêt 68HC11\n", stderr);*/
}	

void lectureUS(int fd, double * ustab)
{
        int i, k, n;
        double usp[ VAHM32_NBRCAPTSUS ];
        double vit = (double) 34300.0;
        double basetps = (double) 32.0e-6;
        unsigned char reception[ VAHM32_NBRCAPTSUS ];
        char buffer[1];
	
		sprintf( buffer,"%c",'E' ); /*lecture donnée*/
		n = write(fd, buffer, 1);
    	if (n < 0)
      		fputs("write() of E failed!\n", stderr);
		n = read(fd,reception,17);
        if (n < 0)
      		fputs("read() of failed!\n", stderr);
		//else 
		//	fputs("read() ok !\n", stderr);
        for( i = 0; i < VAHM32_NBRCAPTSUS; i++ )
        {
                usp[i]=(double)(reception[i]);
    }
        for( i = 1; i < VAHM32_NBRCAPTSUS; i++ )
        {
                usp[i] = usp[i] * vit * basetps;
        }
        for( k = 0; k <= 3; k++ )
        {
                ustab[1+4*k] = usp[1+k];
                ustab[2+4*k] = usp[5+k];
                ustab[3+4*k] = usp[9+k];
                ustab[4+4*k] = usp[13+k];
        }
        for( i = 1; i < VAHM32_NBRCAPTSUS; i++ )
        {
                if( ustab[i] <= 10 )
                ustab[i] = 11;
        }
        ustab[0] = usp[0];
}
/*
int
main (int argc, char *argv[])
{ 
	int fport,i,j;
	double dataUS[VAHM32_NBRCAPTSUS];
	
	fport=open_port(PORTSERIE);
	demarrer68HC11(fport);
	
	for (j=0;j<10;j++)
	{
	lectureUS(fport, dataUS);
		for (i=0;i<VAHM32_NBRCAPTSUS;i++)
	{
		printf("capteur %d = %lf\n",i,dataUS[i]);
	}
	sleep(2);
	}
	stopper68HC11(fport);
	close_port(fport);
	return 0;
}
*/
